<?php

namespace TrafficSumo\cron_job;

use Google\Exception;
use TrafficSumo\http_request\Http_Request;

class Cron_Job{

    function __construct(){
        add_filter( 'cron_schedules', [$this,'traffic_sumo_add_every_24_hours'] );
        // Schedule an action if it's not already scheduled
        if ( ! wp_next_scheduled( 'traffic_sumo_add_every_24_hours' ) ) {
            wp_schedule_event( time(), 'every_24_hours', 'traffic_sumo_add_every_24_hours' );
        }
        add_action( 'traffic_sumo_add_every_24_hours', [$this,'every_24_hours_event_func'] );
    }

    function traffic_sumo_add_every_24_hours( $schedules ) {
        $schedules['every_24_hours'] = array(
            'interval'  => 86400,
            'display'   => __( 'Every 24 hours', 'traffic-sumo' )
        );
        return $schedules;
    }

    function every_24_hours_event_func() {
        $debug_file = TRAFFIC_SUMO_DIR .'debug.log';
        if(!file_exists($debug_file)){
            fopen($debug_file, "w");
        }
        try{
            if(get_option('mozAccessID') && get_option('mozSecretKey')){
                Http_Request::request_moz_api();
            }
            if(get_option( 'gaCredentials') && get_option( 'gaViewID')){
                Http_Request::request_ga_api();
            }
            $content = file_get_contents($debug_file);
            $content .= PHP_EOL;
            $content .= '------------------------------------------------------';
            $content .= PHP_EOL;
            $content .= 'Date: '. date('d-m-y h:i:s:a');
            $content .= PHP_EOL;
            $content .= 'Status: ';
            $content .= PHP_EOL;
            $content .= "Success";
            $content .= PHP_EOL;
            $content .= 'User: ';
            global $current_user; wp_get_current_user();
            if ( is_user_logged_in()){
                $content .= PHP_EOL;
                $content .= $current_user->display_name;
            }
            file_put_contents($debug_file,$content);
        }catch (Exception $err){
            $error = json_decode(json_encode($err->xdebug_message),true);
            $content .= PHP_EOL;
            $content .= '------------------------------------------------------';
            $content .= PHP_EOL;
            $content .= 'Date: '. date('d-m-y h:i:s:a');
            $content .= PHP_EOL;
            $content .= 'Status: ';
            $content .= PHP_EOL;
            $content .= "Failed";
            $content .= PHP_EOL;
            $content .= 'Error: ';
            $content .= PHP_EOL;
            $content .= $error;
            $content .= 'User: ';
            global $current_user; wp_get_current_user();
            if ( is_user_logged_in()){
                $content .= PHP_EOL;
                $content .= $current_user->display_name;
            }
            file_put_contents($debug_file,$content);
        }
    }
}