<?php

namespace TrafficSumo\http_request;


use Google\Exception;
use Google_Client;
use Google_Service_AnalyticsReporting;
use Google_Service_AnalyticsReporting_DateRange;
use Google_Service_AnalyticsReporting_Dimension;
use Google_Service_AnalyticsReporting_GetReportsRequest;
use Google_Service_AnalyticsReporting_Metric;
use Google_Service_AnalyticsReporting_ReportRequest;

class Http_Request{


    /**
     * @throws Exception
     */
    static function initialize_ga_analytics(): Google_Service_AnalyticsReporting
    {
        $KEY_FILE_LOCATION = get_option( 'gaCredentials')['file'];
        // Create and configure a new client object.
        $client = new Google_Client();
        $client->setApplicationName( get_bloginfo('name').'Reporting');
        $client->setAuthConfig($KEY_FILE_LOCATION);
        $client->setScopes(['https://www.googleapis.com/auth/analytics.readonly']);
        return new Google_Service_AnalyticsReporting($client);
    }

    static function get_ga_report_session_three_months($analytics){

        // Replace with your view ID, for example XXXX.
        $VIEW_ID = get_option( 'gaViewID');

        // Create the DateRange object.
        $dateRange = new Google_Service_AnalyticsReporting_DateRange();
        $dateRange->setStartDate(date("Y-m-d",strtotime("-3 Months")));
        $dateRange->setEndDate("today");

        // Create the Metrics object.
        $sessions = new Google_Service_AnalyticsReporting_Metric();
        $sessions->setExpression("ga:pageviews");
        $sessions->setAlias("pageviews");

        // Create the ReportRequest object.
        $request = new Google_Service_AnalyticsReporting_ReportRequest();
        $request->setViewId($VIEW_ID);
        $request->setDateRanges($dateRange);
        $request->setMetrics(array($sessions));

        $body = new Google_Service_AnalyticsReporting_GetReportsRequest();
        $body->setReportRequests( array( $request) );
        return $analytics->reports->batchGet( $body );
    }

    static function get_ga_report_session_one_year($analytics){

        // Replace with your view ID, for example XXXX.
        $VIEW_ID = get_option( 'gaViewID');

        // Create the DateRange object.
        $dateRange = new Google_Service_AnalyticsReporting_DateRange();
        $dateRange->setStartDate(date("Y-m-d",strtotime("-1 Years")));
        $dateRange->setEndDate("today");

        // Create the Metrics object.
        $sessions = new Google_Service_AnalyticsReporting_Metric();
        $sessions->setExpression("ga:pageviews");
        $sessions->setAlias("pageviews");

        // Create the ReportRequest object.
        $request = new Google_Service_AnalyticsReporting_ReportRequest();
        $request->setViewId($VIEW_ID);
        $request->setDateRanges($dateRange);
        $request->setMetrics(array($sessions));

        $body = new Google_Service_AnalyticsReporting_GetReportsRequest();
        $body->setReportRequests( array( $request) );
        return $analytics->reports->batchGet( $body );
    }

    static function get_ga_report_session_country ($analytics){

        // Replace with your view ID, for example XXXX.
        $VIEW_ID = get_option( 'gaViewID');

        // Create the DateRange object.
        $dateRange = new Google_Service_AnalyticsReporting_DateRange();
        $dateRange->setStartDate(date("Y-m-d",strtotime("-1 Years")));
        $dateRange->setEndDate("today");

        // Create the Metrics object.
        $sessions = new Google_Service_AnalyticsReporting_Metric();
        $sessions->setExpression("ga:pageviews");
        $sessions->setAlias("pageviews");

        // Create the Metrics object.
        $dimensions = new Google_Service_AnalyticsReporting_Dimension();
        $dimensions->setName('ga:country');

        // Create the ReportRequest object.
        $request = new Google_Service_AnalyticsReporting_ReportRequest();
        $request->setViewId($VIEW_ID);
        $request->setDateRanges($dateRange);
        $request->setMetrics(array($sessions));
        $request->setDimensions($dimensions);

        $body = new Google_Service_AnalyticsReporting_GetReportsRequest();
        $body->setReportRequests( array( $request) );
        return $analytics->reports->batchGet( $body );
    }

    static function printResults($reports) {
        var_dump($reports);
    }



    /**
     * @throws Exception
     */
    static function request_ga_api(){
        $analytics =  self::initialize_ga_analytics();
        $response_session = self::get_ga_report_session_three_months($analytics)->reports[0]->data->totals[0]->values[0];
        $response_session_year = self::get_ga_report_session_one_year($analytics)->reports[0]->data->totals[0]->values[0];
        $response_session_country = self::get_ga_report_session_country($analytics)->reports[0]->data->rows;

        $country_map = array_map(function ($country) use ($response_session_year) {
            $value = ((int)$country->metrics[0]->values[0] / (int)$response_session_year) * 100;
            $name = $country->dimensions[0];
            return [
                'name'      => $name,
                'values'    => $value
            ];
        },$response_session_country);
        /* Sort array order by value */
        uasort($country_map,function ($a,$b)
        {
            if ($a['values'] == $b['values']) return 0;
            return ($a['values']>$b['values'])?-1:1;
        });
        /* Save maximum three items of array  */

        $country_metric = array_slice($country_map, 0, 3);

        /* Save data */
        get_option( 'page_views') !== null ?  update_option( 'page_views', $response_session, 'yes' ) :   add_option( 'page_views', $response_session, '', 'yes' );
        get_option( 'page_views_year') !== null ?  update_option( 'page_views_year', $response_session_year, 'yes' ) :   add_option( 'page_views_year', $response_session_year, '', 'yes' );
        get_option( 'country_metric') !== null ?  update_option( 'country_metric', $country_metric, 'yes' ) :   add_option( 'country_metric', $country_metric, '', 'yes' );
    }

    static function request_moz_api(){
        $mozAccessID = get_option('mozAccessID') ;
        $mozSecretKey = get_option('mozSecretKey');
        $expires = time() + 300;
        if($mozAccessID && $mozSecretKey){
            $stringToSign = $mozAccessID."\n".$expires;
            $binarySignature = hash_hmac('sha1', $stringToSign, $mozSecretKey, true);
            $urlSafeSignature = urlencode(base64_encode($binarySignature));
            $objectURL = get_home_url();
            $cols = "68719476736";
            $requestUrl = "http://lsapi.seomoz.com/linkscape/url-metrics/".urlencode($objectURL)."?Cols=".$cols."&AccessID=".$mozAccessID."&Expires=".$expires."&Signature=".$urlSafeSignature;
            $options = array(
                CURLOPT_RETURNTRANSFER => true
            );
            $response = json_decode(wp_remote_get( $requestUrl, $options)['body'],true);
            $domain_rating = $response['pda'];
            get_option( 'domain_rating') ?  update_option( 'domain_rating', $domain_rating, 'yes' ) :   add_option( 'domain_rating', $domain_rating, '', 'yes' );
        }
    }
}